# Swarmauri SDK
This repository includes core interfaces, standard ABCs, and standard concrete references of the SwarmaURI Framework.

[![Star on GitHub](https://img.shields.io/github/stars/swarmauri/swarmauri-sdk?style=social)](https://github.com/swarmauri/swarmauri-sdk/stargazers) [![Fork on GitHub](https://img.shields.io/github/forks/swarmauri/swarmauri-sdk?style=social)](https://github.com/swarmauri/swarmauri-sdk/network/members) [![Watch on GitHub](https://img.shields.io/github/watchers/swarmauri/swarmauri-sdk?style=social)](https://github.com/swarmauri/swarmauri-sdk/watchers)


![](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/swarmauri/swarmauri-sdk&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false) ![v0.4.1](https://img.shields.io/badge/Version-v0.4.1-yellow) ![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/swarmauri/swarmauri-sdk/staging.yml) [![License: MIT](https://img.shields.io/badge/License-Apache-yellow.svg)]([https://github.com/swarmauri/swarmauri-sdk/LICENSE](https://github.com/swarmauri/swarmauri-sdk?tab=Apache-2.0-1-ov-file#readme)) 


## Steps to compile python package from source
```bash
pip install swarmauri[full]
```
